==> vacuum-1.1.0.tar.xz: vacuum-1.1.0/src/translations/de/avatars.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="de" sourcelanguage="en">
<context>
    <name>Avatars</name>
    <message>
        <source>Avatar</source>
        <translation>Avatar</translation>
    </message>
    <message>
        <source>Set avatar</source>
        <translation>Avatar setzen</translation>
    </message>
    <message>
        <source>Clear avatar</source>
        <translation>Avatar löschen</translation>
    </message>
    <message>
        <source>Custom picture</source>
        <translation>Eigenes Bild</translation>
    </message>
    <message>
        <source>Set custom picture</source>
        <translation>Eigenes Bild setzen</translation>
    </message>
    <message>
        <source>Clear custom picture</source>
        <translation>Eigenes Bild löschen</translation>
    </message>
    <message>
        <source>Select avatar image</source>
        <translation>Avatarbild auswählen</translation>
    </message>
    <message>
        <source>Image Files (*.png *.jpg *.bmp *.gif)</source>
        <translation>Bild Dateien (*.png *.jpg *.bmp *.gif)</translation>
    </message>
    <message>
        <source>Avatars</source>
        <translation>Avatare</translation>
    </message>
    <message>
        <source>Allows to set and display avatars</source>
        <translation>Erlaubt das Setzen und Anzeigen von Avataren</translation>
    </message>
    <message>
        <source>Show avatars</source>
        <translation></translation>
    </message>
    <message>
        <source>Show empty avatars</source>
        <translation></translation>
    </message>
</context>
</TS>

==> vacuum-1.2.4.tar.xz: vacuum-1.2.4/src/translations/de/avatars.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="de" sourcelanguage="en">
<context>
    <name>Avatars</name>
    <message>
        <source>Avatar</source>
        <translation>Avatar</translation>
    </message>
    <message>
        <source>Set avatar</source>
        <translation>Avatar setzen</translation>
    </message>
    <message>
        <source>Clear avatar</source>
        <translation>Avatar löschen</translation>
    </message>
    <message>
        <source>Custom picture</source>
        <translation>Eigenes Bild</translation>
    </message>
    <message>
        <source>Set custom picture</source>
        <translation>Eigenes Bild setzen</translation>
    </message>
    <message>
        <source>Clear custom picture</source>
        <translation>Eigenes Bild löschen</translation>
    </message>
    <message>
        <source>Select avatar image</source>
        <translation>Avatarbild auswählen</translation>
    </message>
    <message>
        <source>Image Files (*.png *.jpg *.bmp *.gif)</source>
        <translation>Bilddateien (*.png *.jpg *.bmp *.gif)</translation>
    </message>
    <message>
        <source>Avatars</source>
        <translation>Avatare</translation>
    </message>
    <message>
        <source>Allows to set and display avatars</source>
        <translation>Erlaubt das Setzen und Anzeigen von Avataren</translation>
    </message>
    <message>
        <source>Show avatars</source>
        <translation>Avatare anzeigen</translation>
    </message>
    <message>
        <source>Show empty avatars</source>
        <translation>Leere Avatare anzeigen</translation>
    </message>
</context>
</TS>
